# -*- coding: utf-8 -*-

# constants for pollutants names
POLLUTANT_O3_8H = 'o3_8h'
POLLUTANT_O3_1H = 'o3_1h'
POLLUTANT_PM10 = 'pm10'
POLLUTANT_PM25 = 'pm25'
POLLUTANT_CO_1H = 'co_1h'
POLLUTANT_CO_8H = 'co_8h'
POLLUTANT_CO_24H = 'co_24h'
POLLUTANT_SO2_1H = 'so2_1h'
POLLUTANT_SO2_24H = 'so2_24h'
POLLUTANT_NO2_1H = 'no2_1h'
POLLUTANT_NO2_24H = 'no2_24h'

# constants for algorithms, canonical module name
ALGO_EPA = 'aqicalc.algos.epa'
ALGO_MEP = 'aqicalc.algos.mep'
ALGO_CPCB = 'aqicalc.algos.cpcb'
ALGO_IEMA = 'aqicalc.algos.iema'
ALGO_KAQI = 'aqicalc.algos.kaqi'
ALGO_CAQI = 'aqicalc.algos.caqi'
ALGOS = [ALGO_EPA, ALGO_MEP,ALGO_CPCB,ALGO_IEMA,ALGO_KAQI]
